.. image:: https://zenodo.org/badge/4036/kgullikson88/gullikson-scripts.svg
   :target: https://zenodo.org/badge/latestdoi/4036/kgullikson88/gullikson-scripts

Kevin Gullikson's Scripts
============================

This is a variety of packages that I use in my research. This package was made as a convenience to anyone interested in my work, and is not very thoroughly tested. The repository that I have been using the last several years in located `here <https://github.com/kgullikson88/General>`_, but is much more of a pain to install...

If you use this repository in your research, please cite me using the digital object identifier (DOI) above!

Installation
============

If you use anaconda python, use:

.. code:: bash

    conda install h5py pandas scipy matplotlib bokeh==0.10 astropy scikit-learn cython seaborn pytables
    python setup.py install
    
